==> core-io-1.0.0-sources.jar: com/couchbase/client/core/RequestEvent.java <==
/**
 * Copyright (C) 2014 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */
package com.couchbase.client.core;

import com.couchbase.client.core.message.CouchbaseRequest;

/**
 * A pre allocated event which carries a {@link CouchbaseRequest} and associated information.
 *
 * @author Michael Nitschinger
 * @since 1.0
 */
public class RequestEvent {

    /**
     * Contains the current request.
     */
    private CouchbaseRequest request;

    /**
     * Set the new request as a payload for this event.
     *
     * @param request the request to override.
     * @return the {@link RequestEvent} for method chaining.
     */
    public RequestEvent setRequest(final CouchbaseRequest request) {
        this.request = request;
        return this;
    }

    public CouchbaseRequest getRequest() {
        return request;
    }

}

==> core-io-1.2.9-sources.jar: com/couchbase/client/core/RequestEvent.java <==
/**
 * Copyright (C) 2014 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */
package com.couchbase.client.core;

import com.couchbase.client.core.message.CouchbaseRequest;

/**
 * A pre allocated event which carries a {@link CouchbaseRequest} and associated information.
 *
 * @author Michael Nitschinger
 * @since 1.0
 */
public class RequestEvent {

    /**
     * Contains the current request.
     */
    private CouchbaseRequest request;

    /**
     * Set the new request as a payload for this event.
     *
     * @param request the request to override.
     * @return the {@link RequestEvent} for method chaining.
     */
    public RequestEvent setRequest(final CouchbaseRequest request) {
        this.request = request;
        return this;
    }

    public CouchbaseRequest getRequest() {
        return request;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("RequestEvent{");
        sb.append("request=").append(request);
        sb.append('}');
        return sb.toString();
    }
}
